(define (domain assembly)
   (:requirements :adl)
   (:types assembly resource)   ; Individual parts are atomic assemblies
   (:predicates (available ?x - (either resource assembly))
		(complete ?a - assembly)
		(requires ?a - assembly ?r - resource)
		(committed ?r - resource ?a - assembly)
		(incorporated ?part ?whole - assembly)
		(part-of ?part ?whole - assembly)
		(to-be-removed ?part ?whole - assembly)
		(assemble-order ?part1 ?part2 ?whole - assembly)
		(transient-part ?part ?whole - assembly)
		; After ?part1 is included, ?part2 must be removed
		; for the ?whole to be complete:
		(remove-order ?part1 ?part2 ?whole - assembly))

   (:action commit
      :parameters (?res - resource ?as - assembly)
      :precondition (available ?res)
      :effect (and (not (available ?res))
		   (committed ?res ?as)))

   (:action release
      :parameters (?res - resource ?as - assembly)
      :precondition (committed ?res ?as)
      :effect (and (not (committed ?res ?as))
		   (available ?res)))
		
		
   (:action assemble
      :parameters (?part ?whole - assembly)
      :precondition (and (forall (?res - resource)
			    (imply (requires ?whole ?res)
				   (committed ?res ?whole)))
			 (or (part-of ?part ?whole)
			     (transient-part ?part ?whole))
			 (available ?part)
			 (forall (?prev - assembly)
			    (imply (assemble-order ?prev ?part ?whole)
				   (incorporated ?prev ?whole))))
      :effect (and (incorporated ?part ?whole)
		   (not (available ?part))
		   (when (and (not (exists (?p - assembly)
				      (and (part-of ?p ?whole)
	                                   (not (= ?p ?part))
					   (not (incorporated ?p ?whole)))))
			      (not (exists (?tp - assembly)
				      (and (transient-part ?tp ?whole)
					   (incorporated ?tp ?whole)))))
			 (and (complete ?whole)
			      (available ?whole)))))

   ; You can remove the last part added, or a cleanup part at the
   ; end.
   (:action remove
      :parameters (?part ?whole - assembly)
      :vars (?res - resource)
      :precondition (and (forall (?res - resource)
			    (imply (requires ?whole ?res)
				   (committed ?res ?whole)))
			 (incorporated ?part ?whole)
			 (or (and (transient-part ?part ?whole)
				  (forall (?prev - assembly)
				     (imply
				        (remove-order ?prev ?part ?whole)
					(incorporated ?prev ?whole))))
			     (and (part-of ?part ?whole)
				  (not (exists (?prev - assembly)
					  (and (assemble-order
						  ?prev ?part ?whole)
					       (incorporated
						  ?prev ?whole)))))))
      :effect (and (not (incorporated ?part ?whole))
		   (available ?part)
		   (when (and (not (exists (?p - assembly)
				      (and (part-of ?p ?whole)
					   (not (incorporated ?p ?whole)))))
			      (not (exists (?tp - assembly)
				      (and (transient-part ?tp ?whole)
                                           (not (= ?tp ?part))
					   (incorporated ?tp ?whole)))))
			 (and (complete ?whole)
			      (available ?whole))))))
      
(define (problem assembly-test)
   (:domain assembly)
   (:objects lwing rwing fuselage tail lflaps rflaps
	     engine1 engine2 propeller1 propeller2 linchpin
	     airplane - assembly
	     scaffold - resource)
   (:init (available scaffold)
	  (available linchpin)
	  (available propeller1)
	  (available propeller2)
          (available lflaps)
          (available rflaps)
          (available fuselage)

          (requires lwing scaffold)
	  (requires rwing scaffold)
	  (requires tail scaffold)
	  (requires airplane scaffold)
	  (transient-part linchpin engine1)
	  (transient-part linchpin engine2)
	  (part-of propeller1 engine1)
	  (part-of propeller2 engine2)
	  (part-of engine1 lwing)
	  (part-of engine2 rwing)
	  (part-of lflaps lwing)
	  (part-of rflaps rwing)
	  (part-of lwing airplane)
	  (part-of rwing airplane)
	  (part-of fuselage airplane)
	  (part-of linchpin tail)
	  (part-of tail airplane)

	  (assemble-order linchpin propeller1 engine1)
	  (assemble-order linchpin propeller2 engine2)
	  (remove-order propeller1 linchpin engine1)
	  (remove-order propeller2 linchpin engine2)
	  (assemble-order fuselage lwing airplane)
	  (assemble-order fuselage rwing airplane)
	  (assemble-order fuselage tail airplane))
   (:goal (complete airplane)))

(defvar assembly-0-solution*
        '((assemble linchpin engine1)
	  (assemble propeller1 engine1)
	  (remove linchpin engine1)
	  (assemble linchpin engine2)
	  (assemble propeller2 engine2)
	  (remove linchpin engine2)

	  (commit scaffold rwing)
	  (assemble engine2 rwing)
	  (assemble rflaps rwing)
	  (release scaffold rwing)

	  (commit scaffold lwing)
	  (assemble engine1 lwing)
	  (assemble lflaps lwing)
	  (release scaffold lwing)

	  (commit scaffold tail)
	  (assemble linchpin tail)
	  (release scaffold tail)

	  (commit scaffold airplane)
	  (assemble fuselage airplane)
	  (assemble lwing airplane)
	  (assemble rwing airplane)
	  (assemble tail airplane)))

(DEFINE (PROBLEM ASSEM-0)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS FROB SOCKET KLUDGE PLUG WIDGET MOUNT WHATSIS DOODAD HACK
             GIMCRACK - ASSEMBLY
             FILE - RESOURCE)
   (:INIT (AVAILABLE KLUDGE)
          (AVAILABLE PLUG)
          (AVAILABLE WIDGET)
          (AVAILABLE WHATSIS)
          (AVAILABLE HACK)
          (AVAILABLE GIMCRACK)
          (REQUIRES SOCKET FILE)
          (REQUIRES DOODAD FILE)
          (PART-OF SOCKET FROB)
          (PART-OF MOUNT FROB)
          (PART-OF KLUDGE SOCKET)
          (PART-OF PLUG SOCKET)
          (PART-OF WIDGET SOCKET)
          (PART-OF WHATSIS MOUNT)
          (PART-OF DOODAD MOUNT)
          (PART-OF HACK DOODAD)
          (PART-OF GIMCRACK DOODAD)
          (ASSEMBLE-ORDER MOUNT SOCKET FROB)
          (ASSEMBLE-ORDER KLUDGE WIDGET SOCKET)
          (ASSEMBLE-ORDER PLUG KLUDGE SOCKET)
          (ASSEMBLE-ORDER GIMCRACK HACK DOODAD))
   (:GOAL (COMPLETE FROB)))

(DEFINE (PROBLEM ASSEM-1)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS HOOZAWHATSIE PLUG HACK DOODAD WIRE TUBE VALVE COIL
             FASTENER GIMCRACK KLUDGE - ASSEMBLY
             CLAMP HAMMER - RESOURCE)
   (:INIT (AVAILABLE HACK)
          (AVAILABLE DOODAD)
          (AVAILABLE WIRE)
          (AVAILABLE TUBE)
          (AVAILABLE VALVE)
          (AVAILABLE FASTENER)
          (AVAILABLE GIMCRACK)
          (AVAILABLE KLUDGE)
          (REQUIRES PLUG HAMMER)
          (REQUIRES COIL CLAMP)
          (PART-OF PLUG HOOZAWHATSIE)
          (PART-OF COIL HOOZAWHATSIE)
          (PART-OF HACK PLUG)
          (PART-OF DOODAD PLUG)
          (PART-OF WIRE PLUG)
          (PART-OF TUBE PLUG)
          (PART-OF VALVE PLUG)
          (PART-OF FASTENER COIL)
          (PART-OF GIMCRACK COIL)
          (PART-OF KLUDGE COIL)
          (ASSEMBLE-ORDER COIL PLUG HOOZAWHATSIE)
          (ASSEMBLE-ORDER DOODAD HACK PLUG)
          (ASSEMBLE-ORDER WIRE HACK PLUG)
          (ASSEMBLE-ORDER VALVE DOODAD PLUG))
   (:GOAL (COMPLETE HOOZAWHATSIE)))

(DEFINE (PROBLEM ASSEM-2)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS KLUDGE HOOZAWHATSIE WIDGET THINGUMBOB SPROCKET COIL
             BRACKET FROB UNIT VALVE FASTENER - ASSEMBLY
             SCOPE HAMMER - RESOURCE)
   (:INIT (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE COIL)
          (AVAILABLE BRACKET)
          (AVAILABLE UNIT)
          (AVAILABLE VALVE)
          (AVAILABLE FASTENER)
          (REQUIRES WIDGET HAMMER)
          (REQUIRES SPROCKET SCOPE)
          (REQUIRES FROB HAMMER)
          (PART-OF HOOZAWHATSIE KLUDGE)
          (PART-OF WIDGET KLUDGE)
          (PART-OF SPROCKET KLUDGE)
          (PART-OF COIL WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (TRANSIENT-PART COIL SPROCKET)
          (PART-OF BRACKET SPROCKET)
          (PART-OF FROB SPROCKET)
          (PART-OF UNIT FROB)
          (PART-OF VALVE FROB)
          (PART-OF FASTENER FROB)
          (ASSEMBLE-ORDER HOOZAWHATSIE SPROCKET KLUDGE)
          (ASSEMBLE-ORDER COIL BRACKET WIDGET)
          (ASSEMBLE-ORDER COIL BRACKET SPROCKET)
          (REMOVE-ORDER BRACKET COIL SPROCKET)
          (ASSEMBLE-ORDER FROB COIL SPROCKET)
          (ASSEMBLE-ORDER UNIT FASTENER FROB))
   (:GOAL (COMPLETE KLUDGE)))

(DEFINE (PROBLEM ASSEM-3)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET WIDGET FOOBAR CONNECTOR THINGUMBOB VALVE WIRE
             BRACKET HACK PLUG FASTENER DEVICE KLUDGE - ASSEMBLY
             PLIERS - RESOURCE)
   (:INIT (AVAILABLE WIDGET)
          (AVAILABLE FOOBAR)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE VALVE)
          (AVAILABLE WIRE)
          (AVAILABLE HACK)
          (AVAILABLE PLUG)
          (AVAILABLE DEVICE)
          (AVAILABLE KLUDGE)
          (REQUIRES CONNECTOR PLIERS)
          (REQUIRES BRACKET PLIERS)
          (REQUIRES FASTENER PLIERS)
          (PART-OF WIDGET SOCKET)
          (PART-OF FOOBAR SOCKET)
          (PART-OF CONNECTOR SOCKET)
          (PART-OF BRACKET SOCKET)
          (PART-OF FASTENER SOCKET)
          (PART-OF THINGUMBOB CONNECTOR)
          (PART-OF VALVE CONNECTOR)
          (PART-OF WIRE CONNECTOR)
          (PART-OF HACK BRACKET)
          (PART-OF PLUG BRACKET)
          (PART-OF DEVICE FASTENER)
          (PART-OF KLUDGE FASTENER)
          (ASSEMBLE-ORDER WIDGET CONNECTOR SOCKET)
          (ASSEMBLE-ORDER WIDGET FOOBAR SOCKET)
          (ASSEMBLE-ORDER CONNECTOR FOOBAR SOCKET)
          (ASSEMBLE-ORDER BRACKET FASTENER SOCKET)
          (ASSEMBLE-ORDER DEVICE KLUDGE FASTENER))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-4)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS KLUDGE BRACKET WHATSIS SPROCKET DOODAD CONTRAPTION
             WIRE GIMCRACK PLUG HOOZAWHATSIE THINGUMBOB COIL FASTENER
             WIDGET - ASSEMBLY
             CHARGER PLIERS - RESOURCE)
   (:INIT (AVAILABLE SPROCKET)
          (AVAILABLE DOODAD)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WIRE)
          (AVAILABLE PLUG)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE FASTENER)
          (AVAILABLE WIDGET)
          (REQUIRES BRACKET CHARGER)
          (REQUIRES WHATSIS PLIERS)
          (REQUIRES GIMCRACK PLIERS)
          (REQUIRES COIL PLIERS)
          (PART-OF BRACKET KLUDGE)
          (PART-OF COIL KLUDGE)
          (PART-OF WHATSIS BRACKET)
          (PART-OF GIMCRACK BRACKET)
          (PART-OF SPROCKET WHATSIS)
          (PART-OF DOODAD WHATSIS)
          (PART-OF CONTRAPTION WHATSIS)
          (PART-OF WIRE WHATSIS)
          (PART-OF PLUG GIMCRACK)
          (PART-OF HOOZAWHATSIE GIMCRACK)
          (PART-OF THINGUMBOB GIMCRACK)
          (PART-OF FASTENER COIL)
          (PART-OF WIDGET COIL)
          (ASSEMBLE-ORDER BRACKET COIL KLUDGE)
          (ASSEMBLE-ORDER WHATSIS GIMCRACK BRACKET)
          (ASSEMBLE-ORDER WIRE CONTRAPTION WHATSIS)
          (ASSEMBLE-ORDER PLUG THINGUMBOB GIMCRACK))
   (:GOAL (COMPLETE KLUDGE)))

(DEFINE (PROBLEM ASSEM-5)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS WIDGET PLUG SOCKET HOOZAWHATSIE CONTRAPTION DOODAD
             VALVE SPROCKET FROB THINGUMBOB FOOBAR FASTENER BRACKET
             WHATSIS CONNECTOR - ASSEMBLY
             TWEEZERS - RESOURCE)
   (:INIT (AVAILABLE SOCKET)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE DOODAD)
          (AVAILABLE VALVE)
          (AVAILABLE SPROCKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE FASTENER)
          (AVAILABLE WHATSIS)
          (AVAILABLE CONNECTOR)
          (REQUIRES PLUG TWEEZERS)
          (REQUIRES FROB TWEEZERS)
          (PART-OF PLUG WIDGET)
          (PART-OF FROB WIDGET)
          (PART-OF SOCKET PLUG)
          (PART-OF HOOZAWHATSIE PLUG)
          (PART-OF CONTRAPTION PLUG)
          (PART-OF DOODAD PLUG)
          (PART-OF VALVE PLUG)
          (PART-OF SPROCKET PLUG)
          (PART-OF THINGUMBOB FROB)
          (PART-OF BRACKET FROB)
          (PART-OF FOOBAR THINGUMBOB)
          (PART-OF FASTENER THINGUMBOB)
          (PART-OF WHATSIS BRACKET)
          (PART-OF CONNECTOR BRACKET)
          (ASSEMBLE-ORDER PLUG FROB WIDGET)
          (ASSEMBLE-ORDER SOCKET DOODAD PLUG)
          (ASSEMBLE-ORDER DOODAD CONTRAPTION PLUG)
          (ASSEMBLE-ORDER SPROCKET HOOZAWHATSIE PLUG)
          (ASSEMBLE-ORDER THINGUMBOB BRACKET FROB)
          (ASSEMBLE-ORDER CONNECTOR WHATSIS BRACKET))
   (:GOAL (COMPLETE WIDGET)))

(DEFINE (PROBLEM ASSEM-6)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS MOUNT HOOZAWHATSIE BRACKET TUBE SOCKET HACK WHATSIS
             WIDGET CONNECTOR FASTENER VALVE GIMCRACK THINGUMBOB DEVICE
             FOOBAR - ASSEMBLY
             CHARGER HAMMER - RESOURCE)
   (:INIT (AVAILABLE BRACKET)
          (AVAILABLE TUBE)
          (AVAILABLE SOCKET)
          (AVAILABLE WIDGET)
          (AVAILABLE CONNECTOR)
          (AVAILABLE VALVE)
          (AVAILABLE GIMCRACK)
          (AVAILABLE DEVICE)
          (AVAILABLE FOOBAR)
          (REQUIRES HOOZAWHATSIE CHARGER)
          (REQUIRES HACK CHARGER)
          (REQUIRES WHATSIS HAMMER)
          (REQUIRES FASTENER HAMMER)
          (REQUIRES THINGUMBOB HAMMER)
          (PART-OF HOOZAWHATSIE MOUNT)
          (PART-OF HACK MOUNT)
          (PART-OF THINGUMBOB MOUNT)
          (PART-OF BRACKET HOOZAWHATSIE)
          (PART-OF DEVICE HOOZAWHATSIE)
          (PART-OF TUBE HOOZAWHATSIE)
          (PART-OF SOCKET HOOZAWHATSIE)
          (PART-OF WHATSIS HACK)
          (PART-OF FASTENER HACK)
          (PART-OF WIDGET WHATSIS)
          (PART-OF CONNECTOR WHATSIS)
          (PART-OF VALVE FASTENER)
          (PART-OF GIMCRACK FASTENER)
          (TRANSIENT-PART DEVICE THINGUMBOB)
          (PART-OF FOOBAR THINGUMBOB)
          (ASSEMBLE-ORDER DEVICE FOOBAR HOOZAWHATSIE)
          (ASSEMBLE-ORDER SOCKET DEVICE HOOZAWHATSIE)
          (ASSEMBLE-ORDER WHATSIS FASTENER HACK)
          (ASSEMBLE-ORDER CONNECTOR WIDGET WHATSIS)
          (ASSEMBLE-ORDER VALVE GIMCRACK FASTENER)
          (ASSEMBLE-ORDER DEVICE FOOBAR THINGUMBOB)
          (REMOVE-ORDER FOOBAR DEVICE THINGUMBOB))
   (:GOAL (COMPLETE MOUNT)))

(DEFINE (PROBLEM ASSEM-7)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS WIDGET HOOZAWHATSIE UNIT FASTENER SOCKET PLUG WIRE
             CONTRAPTION FOOBAR KLUDGE THINGUMBOB HACK WHATSIS CONNECTOR DEVICE
             COIL BRACKET - ASSEMBLY
             HAMMOCK CLAMP - RESOURCE)
   (:INIT (AVAILABLE UNIT)
          (AVAILABLE FASTENER)
          (AVAILABLE PLUG)
          (AVAILABLE WIRE)
          (AVAILABLE FOOBAR)
          (AVAILABLE KLUDGE)
          (AVAILABLE HACK)
          (AVAILABLE WHATSIS)
          (AVAILABLE CONNECTOR)
          (AVAILABLE DEVICE)
          (AVAILABLE COIL)
          (AVAILABLE BRACKET)
          (REQUIRES HOOZAWHATSIE CLAMP)
          (REQUIRES SOCKET CLAMP)
          (REQUIRES CONTRAPTION HAMMOCK)
          (REQUIRES THINGUMBOB CLAMP)
          (PART-OF HOOZAWHATSIE WIDGET)
          (PART-OF SOCKET WIDGET)
          (PART-OF CONTRAPTION WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (PART-OF UNIT HOOZAWHATSIE)
          (PART-OF FASTENER HOOZAWHATSIE)
          (PART-OF PLUG SOCKET)
          (PART-OF WIRE SOCKET)
          (PART-OF FOOBAR CONTRAPTION)
          (PART-OF KLUDGE CONTRAPTION)
          (PART-OF HACK THINGUMBOB)
          (PART-OF WHATSIS THINGUMBOB)
          (PART-OF CONNECTOR THINGUMBOB)
          (PART-OF DEVICE THINGUMBOB)
          (PART-OF COIL THINGUMBOB)
          (PART-OF BRACKET THINGUMBOB)
          (ASSEMBLE-ORDER CONTRAPTION THINGUMBOB WIDGET)
          (ASSEMBLE-ORDER FASTENER UNIT HOOZAWHATSIE)
          (ASSEMBLE-ORDER WIRE PLUG SOCKET)
          (ASSEMBLE-ORDER FOOBAR KLUDGE CONTRAPTION)
          (ASSEMBLE-ORDER WHATSIS CONNECTOR THINGUMBOB)
          (ASSEMBLE-ORDER CONNECTOR BRACKET THINGUMBOB)
          (ASSEMBLE-ORDER CONNECTOR HACK THINGUMBOB)
          (ASSEMBLE-ORDER DEVICE COIL THINGUMBOB)
          (ASSEMBLE-ORDER COIL WHATSIS THINGUMBOB))
   (:GOAL (COMPLETE WIDGET)))

(DEFINE (PROBLEM ASSEM-8)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS GIMCRACK COIL CONTRAPTION FROB DOODAD WIRE BRACKET
             DEVICE WIDGET MOUNT KLUDGE FASTENER HACK SOCKET PLUG TUBE
             - ASSEMBLY
             HAMMOCK PLIERS - RESOURCE)
   (:INIT (AVAILABLE CONTRAPTION)
          (AVAILABLE FROB)
          (AVAILABLE DOODAD)
          (AVAILABLE WIRE)
          (AVAILABLE BRACKET)
          (AVAILABLE WIDGET)
          (AVAILABLE MOUNT)
          (AVAILABLE KLUDGE)
          (AVAILABLE HACK)
          (AVAILABLE SOCKET)
          (AVAILABLE PLUG)
          (AVAILABLE TUBE)
          (REQUIRES COIL HAMMOCK)
          (REQUIRES DEVICE PLIERS)
          (REQUIRES FASTENER HAMMOCK)
          (PART-OF COIL GIMCRACK)
          (PART-OF DEVICE GIMCRACK)
          (PART-OF FASTENER GIMCRACK)
          (TRANSIENT-PART CONTRAPTION COIL)
          (PART-OF FROB COIL)
          (PART-OF DOODAD COIL)
          (PART-OF WIRE COIL)
          (TRANSIENT-PART BRACKET COIL)
          (PART-OF WIDGET DEVICE)
          (PART-OF CONTRAPTION DEVICE)
          (PART-OF MOUNT DEVICE)
          (PART-OF KLUDGE DEVICE)
          (PART-OF BRACKET FASTENER)
          (PART-OF HACK FASTENER)
          (PART-OF SOCKET FASTENER)
          (PART-OF PLUG FASTENER)
          (PART-OF TUBE FASTENER)
          (ASSEMBLE-ORDER CONTRAPTION DOODAD COIL)
          (ASSEMBLE-ORDER CONTRAPTION FROB COIL)
          (REMOVE-ORDER DOODAD CONTRAPTION COIL)
          (ASSEMBLE-ORDER DOODAD BRACKET COIL)
          (ASSEMBLE-ORDER BRACKET FROB COIL)
          (REMOVE-ORDER FROB BRACKET COIL)
          (ASSEMBLE-ORDER WIDGET KLUDGE DEVICE)
          (ASSEMBLE-ORDER CONTRAPTION DOODAD DEVICE)
          (ASSEMBLE-ORDER CONTRAPTION FROB DEVICE)
          (ASSEMBLE-ORDER MOUNT WIDGET DEVICE)
          (ASSEMBLE-ORDER BRACKET FROB FASTENER)
          (ASSEMBLE-ORDER PLUG SOCKET FASTENER))
   (:GOAL (COMPLETE GIMCRACK)))

(DEFINE (PROBLEM ASSEM-9)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS WHATSIS MOUNT WIRE FROB GIMCRACK TUBE DOODAD PLUG
             CONNECTOR FOOBAR DEVICE WIDGET KLUDGE BRACKET FASTENER HACK UNIT
             HOOZAWHATSIE - ASSEMBLY
             SCAFFOLD SCALPEL SCOPE - RESOURCE)
   (:INIT (AVAILABLE WIRE)
          (AVAILABLE FROB)
          (AVAILABLE TUBE)
          (AVAILABLE DOODAD)
          (AVAILABLE PLUG)
          (AVAILABLE CONNECTOR)
          (AVAILABLE FOOBAR)
          (AVAILABLE DEVICE)
          (AVAILABLE BRACKET)
          (AVAILABLE FASTENER)
          (AVAILABLE UNIT)
          (AVAILABLE HOOZAWHATSIE)
          (REQUIRES MOUNT SCAFFOLD)
          (REQUIRES GIMCRACK SCALPEL)
          (REQUIRES WIDGET SCOPE)
          (REQUIRES KLUDGE SCOPE)
          (REQUIRES HACK SCOPE)
          (PART-OF MOUNT WHATSIS)
          (PART-OF GIMCRACK WHATSIS)
          (PART-OF WIDGET WHATSIS)
          (PART-OF WIRE MOUNT)
          (PART-OF FROB MOUNT)
          (PART-OF KLUDGE MOUNT)
          (PART-OF TUBE GIMCRACK)
          (PART-OF DOODAD GIMCRACK)
          (PART-OF PLUG GIMCRACK)
          (PART-OF CONNECTOR GIMCRACK)
          (PART-OF FOOBAR GIMCRACK)
          (PART-OF DEVICE GIMCRACK)
          (TRANSIENT-PART KLUDGE WIDGET)
          (PART-OF HACK WIDGET)
          (PART-OF BRACKET KLUDGE)
          (PART-OF FASTENER KLUDGE)
          (PART-OF UNIT HACK)
          (PART-OF HOOZAWHATSIE HACK)
          (ASSEMBLE-ORDER GIMCRACK WIDGET WHATSIS)
          (ASSEMBLE-ORDER WIRE FROB MOUNT)
          (ASSEMBLE-ORDER KLUDGE HACK MOUNT)
          (ASSEMBLE-ORDER KLUDGE HACK MOUNT)
          (ASSEMBLE-ORDER TUBE DOODAD GIMCRACK)
          (ASSEMBLE-ORDER CONNECTOR PLUG GIMCRACK)
          (ASSEMBLE-ORDER FOOBAR CONNECTOR GIMCRACK)
          (ASSEMBLE-ORDER FOOBAR PLUG GIMCRACK)
          (ASSEMBLE-ORDER DEVICE TUBE GIMCRACK)
          (ASSEMBLE-ORDER KLUDGE HACK WIDGET)
          (ASSEMBLE-ORDER KLUDGE HACK WIDGET)
          (REMOVE-ORDER HACK KLUDGE WIDGET)
          (ASSEMBLE-ORDER FASTENER BRACKET KLUDGE)
          (ASSEMBLE-ORDER HOOZAWHATSIE UNIT HACK))
   (:GOAL (COMPLETE WHATSIS)))

(DEFINE (PROBLEM ASSEM-10)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS DEVICE TUBE CONNECTOR WIDGET SOCKET FROB UNIT GIMCRACK
             WHATSIS HACK HOOZAWHATSIE CONTRAPTION SPROCKET VALVE MOUNT
             PLUG FOOBAR - ASSEMBLY
             SCALPEL SCOPE SCAFFOLD - RESOURCE)
   (:INIT (AVAILABLE CONNECTOR)
          (AVAILABLE WIDGET)
          (AVAILABLE SOCKET)
          (AVAILABLE FROB)
          (AVAILABLE UNIT)
          (AVAILABLE WHATSIS)
          (AVAILABLE HACK)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE SPROCKET)
          (AVAILABLE PLUG)
          (AVAILABLE FOOBAR)
          (REQUIRES GIMCRACK SCAFFOLD)
          (REQUIRES VALVE SCALPEL)
          (REQUIRES MOUNT SCOPE)
          (PART-OF TUBE DEVICE)
          (PART-OF GIMCRACK DEVICE)
          (PART-OF VALVE DEVICE)
          (PART-OF CONNECTOR TUBE)
          (TRANSIENT-PART WIDGET TUBE)
          (PART-OF SOCKET TUBE)
          (PART-OF FROB TUBE)
          (PART-OF UNIT TUBE)
          (PART-OF WHATSIS GIMCRACK)
          (PART-OF HACK GIMCRACK)
          (PART-OF HOOZAWHATSIE GIMCRACK)
          (PART-OF CONTRAPTION GIMCRACK)
          (PART-OF SPROCKET GIMCRACK)
          (PART-OF WIDGET VALVE)
          (PART-OF MOUNT VALVE)
          (PART-OF PLUG MOUNT)
          (PART-OF FOOBAR MOUNT)
          (ASSEMBLE-ORDER GIMCRACK VALVE DEVICE)
          (ASSEMBLE-ORDER GIMCRACK TUBE DEVICE)
          (ASSEMBLE-ORDER WIDGET SOCKET TUBE)
          (REMOVE-ORDER SOCKET WIDGET TUBE)
          (ASSEMBLE-ORDER SOCKET FROB TUBE)
          (ASSEMBLE-ORDER UNIT WIDGET TUBE)
          (ASSEMBLE-ORDER UNIT FROB TUBE)
          (ASSEMBLE-ORDER WHATSIS HOOZAWHATSIE GIMCRACK)
          (ASSEMBLE-ORDER SPROCKET HOOZAWHATSIE GIMCRACK)
          (ASSEMBLE-ORDER WIDGET SOCKET VALVE)
          (ASSEMBLE-ORDER MOUNT WIDGET VALVE)
          (ASSEMBLE-ORDER FOOBAR PLUG MOUNT))
   (:GOAL (COMPLETE DEVICE)))

(DEFINE (PROBLEM ASSEM-11)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS TUBE CONNECTOR VALVE THINGUMBOB FOOBAR WHATSIS
             HOOZAWHATSIE COIL HACK DEVICE PLUG MOUNT SPROCKET FROB UNIT
             CONTRAPTION WIRE FASTENER SOCKET - ASSEMBLY
             CHARGER TWEEZERS PLIERS - RESOURCE)
   (:INIT (AVAILABLE VALVE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE WHATSIS)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE HACK)
          (AVAILABLE DEVICE)
          (AVAILABLE PLUG)
          (AVAILABLE MOUNT)
          (AVAILABLE FROB)
          (AVAILABLE UNIT)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WIRE)
          (AVAILABLE FASTENER)
          (AVAILABLE SOCKET)
          (REQUIRES CONNECTOR PLIERS)
          (REQUIRES FOOBAR TWEEZERS)
          (REQUIRES COIL PLIERS)
          (REQUIRES SPROCKET CHARGER)
          (PART-OF CONNECTOR TUBE)
          (PART-OF FOOBAR TUBE)
          (PART-OF COIL TUBE)
          (PART-OF SPROCKET TUBE)
          (PART-OF VALVE CONNECTOR)
          (PART-OF THINGUMBOB CONNECTOR)
          (PART-OF DEVICE CONNECTOR)
          (PART-OF WHATSIS FOOBAR)
          (PART-OF HOOZAWHATSIE FOOBAR)
          (PART-OF HACK FOOBAR)
          (TRANSIENT-PART HACK COIL)
          (TRANSIENT-PART DEVICE COIL)
          (PART-OF PLUG COIL)
          (PART-OF MOUNT COIL)
          (PART-OF FROB SPROCKET)
          (PART-OF UNIT SPROCKET)
          (PART-OF CONTRAPTION SPROCKET)
          (PART-OF WIRE SPROCKET)
          (PART-OF FASTENER SPROCKET)
          (PART-OF SOCKET SPROCKET)
          (ASSEMBLE-ORDER COIL SPROCKET TUBE)
          (ASSEMBLE-ORDER DEVICE PLUG CONNECTOR)
          (ASSEMBLE-ORDER DEVICE PLUG CONNECTOR)
          (ASSEMBLE-ORDER HACK MOUNT FOOBAR)
          (ASSEMBLE-ORDER HACK MOUNT COIL)
          (REMOVE-ORDER MOUNT HACK COIL)
          (ASSEMBLE-ORDER DEVICE PLUG COIL)
          (ASSEMBLE-ORDER DEVICE PLUG COIL)
          (REMOVE-ORDER PLUG DEVICE COIL)
          (ASSEMBLE-ORDER PLUG HACK COIL)
          (ASSEMBLE-ORDER UNIT FROB SPROCKET)
          (ASSEMBLE-ORDER WIRE CONTRAPTION SPROCKET)
          (ASSEMBLE-ORDER SOCKET FROB SPROCKET))
   (:GOAL (COMPLETE TUBE)))

(DEFINE (PROBLEM ASSEM-12)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET HOOZAWHATSIE COIL DEVICE PLUG SPROCKET FROB
             CONTRAPTION THINGUMBOB WHATSIS CONNECTOR UNIT DOODAD WIDGET
             GIMCRACK FASTENER TUBE HACK MOUNT VALVE FOOBAR BRACKET
             - ASSEMBLY
             TWEEZERS HAMMER - RESOURCE)
   (:INIT (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE COIL)
          (AVAILABLE PLUG)
          (AVAILABLE SPROCKET)
          (AVAILABLE FROB)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WHATSIS)
          (AVAILABLE CONNECTOR)
          (AVAILABLE UNIT)
          (AVAILABLE DOODAD)
          (AVAILABLE WIDGET)
          (AVAILABLE GIMCRACK)
          (AVAILABLE HACK)
          (AVAILABLE MOUNT)
          (AVAILABLE FOOBAR)
          (AVAILABLE BRACKET)
          (REQUIRES THINGUMBOB HAMMER)
          (REQUIRES FASTENER HAMMER)
          (REQUIRES TUBE HAMMER)
          (REQUIRES VALVE HAMMER)
          (PART-OF HOOZAWHATSIE SOCKET)
          (PART-OF COIL SOCKET)
          (PART-OF DEVICE SOCKET)
          (PART-OF THINGUMBOB SOCKET)
          (PART-OF FASTENER SOCKET)
          (PART-OF PLUG DEVICE)
          (PART-OF SPROCKET DEVICE)
          (PART-OF FROB DEVICE)
          (PART-OF CONTRAPTION DEVICE)
          (PART-OF WHATSIS THINGUMBOB)
          (PART-OF CONNECTOR THINGUMBOB)
          (PART-OF UNIT THINGUMBOB)
          (PART-OF DOODAD THINGUMBOB)
          (PART-OF WIDGET THINGUMBOB)
          (PART-OF GIMCRACK THINGUMBOB)
          (PART-OF TUBE FASTENER)
          (PART-OF VALVE FASTENER)
          (PART-OF HACK TUBE)
          (PART-OF MOUNT TUBE)
          (PART-OF FOOBAR VALVE)
          (PART-OF BRACKET VALVE)
          (ASSEMBLE-ORDER FROB PLUG DEVICE)
          (ASSEMBLE-ORDER FROB CONTRAPTION DEVICE)
          (ASSEMBLE-ORDER CONTRAPTION PLUG DEVICE)
          (ASSEMBLE-ORDER WHATSIS WIDGET THINGUMBOB)
          (ASSEMBLE-ORDER WHATSIS DOODAD THINGUMBOB)
          (ASSEMBLE-ORDER DOODAD CONNECTOR THINGUMBOB))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-13)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SPROCKET MOUNT TUBE WIRE DEVICE KLUDGE VALVE
             HOOZAWHATSIE COIL SOCKET CONNECTOR FASTENER DOODAD FROB CONTRAPTION
             WHATSIS WIDGET BRACKET UNIT HACK FOOBAR GIMCRACK THINGUMBOB
             - ASSEMBLY
             HAMMER - RESOURCE)
   (:INIT (AVAILABLE TUBE)
          (AVAILABLE WIRE)
          (AVAILABLE KLUDGE)
          (AVAILABLE VALVE)
          (AVAILABLE COIL)
          (AVAILABLE SOCKET)
          (AVAILABLE FASTENER)
          (AVAILABLE DOODAD)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE WHATSIS)
          (AVAILABLE BRACKET)
          (AVAILABLE UNIT)
          (AVAILABLE HACK)
          (AVAILABLE FOOBAR)
          (AVAILABLE GIMCRACK)
          (AVAILABLE THINGUMBOB)
          (REQUIRES MOUNT HAMMER)
          (REQUIRES HOOZAWHATSIE HAMMER)
          (REQUIRES CONNECTOR HAMMER)
          (REQUIRES WIDGET HAMMER)
          (PART-OF MOUNT SPROCKET)
          (PART-OF HOOZAWHATSIE SPROCKET)
          (PART-OF CONNECTOR SPROCKET)
          (PART-OF WIDGET SPROCKET)
          (PART-OF TUBE MOUNT)
          (PART-OF WIRE MOUNT)
          (PART-OF DEVICE MOUNT)
          (PART-OF KLUDGE DEVICE)
          (PART-OF VALVE DEVICE)
          (PART-OF COIL HOOZAWHATSIE)
          (PART-OF SOCKET HOOZAWHATSIE)
          (PART-OF FASTENER CONNECTOR)
          (PART-OF DOODAD CONNECTOR)
          (PART-OF FROB CONNECTOR)
          (PART-OF CONTRAPTION FROB)
          (PART-OF WHATSIS FROB)
          (PART-OF BRACKET WIDGET)
          (PART-OF UNIT WIDGET)
          (PART-OF HACK WIDGET)
          (PART-OF FOOBAR WIDGET)
          (PART-OF GIMCRACK WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (ASSEMBLE-ORDER WIDGET CONNECTOR SPROCKET)
          (ASSEMBLE-ORDER WIDGET MOUNT SPROCKET)
          (ASSEMBLE-ORDER WIRE TUBE MOUNT)
          (ASSEMBLE-ORDER DEVICE WIRE MOUNT)
          (ASSEMBLE-ORDER KLUDGE VALVE DEVICE)
          (ASSEMBLE-ORDER SOCKET COIL HOOZAWHATSIE)
          (ASSEMBLE-ORDER DOODAD FASTENER CONNECTOR)
          (ASSEMBLE-ORDER FOOBAR GIMCRACK WIDGET)
          (ASSEMBLE-ORDER FOOBAR UNIT WIDGET))
   (:GOAL (COMPLETE SPROCKET)))

(DEFINE (PROBLEM ASSEM-14)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET BRACKET HACK KLUDGE THINGUMBOB PLUG TUBE DOODAD
             GIMCRACK CONNECTOR SPROCKET FOOBAR FROB WHATSIS DEVICE
             CONTRAPTION WIDGET VALVE MOUNT - ASSEMBLY
             PLIERS CLAMP HAMMOCK - RESOURCE)
   (:INIT (AVAILABLE KLUDGE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE TUBE)
          (AVAILABLE DOODAD)
          (AVAILABLE GIMCRACK)
          (AVAILABLE SPROCKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE FROB)
          (AVAILABLE DEVICE)
          (AVAILABLE WIDGET)
          (AVAILABLE VALVE)
          (AVAILABLE MOUNT)
          (REQUIRES BRACKET PLIERS)
          (REQUIRES HACK HAMMOCK)
          (REQUIRES PLUG CLAMP)
          (REQUIRES CONNECTOR PLIERS)
          (REQUIRES WHATSIS PLIERS)
          (REQUIRES CONTRAPTION CLAMP)
          (PART-OF BRACKET SOCKET)
          (PART-OF PLUG SOCKET)
          (PART-OF CONNECTOR SOCKET)
          (PART-OF WHATSIS SOCKET)
          (PART-OF DOODAD BRACKET)
          (PART-OF HACK BRACKET)
          (TRANSIENT-PART KLUDGE HACK)
          (PART-OF THINGUMBOB HACK)
          (TRANSIENT-PART TUBE PLUG)
          (TRANSIENT-PART DOODAD PLUG)
          (PART-OF GIMCRACK PLUG)
          (TRANSIENT-PART SPROCKET CONNECTOR)
          (PART-OF FOOBAR CONNECTOR)
          (PART-OF FROB CONNECTOR)
          (PART-OF TUBE WHATSIS)
          (PART-OF DEVICE WHATSIS)
          (PART-OF CONTRAPTION WHATSIS)
          (PART-OF WIDGET CONTRAPTION)
          (PART-OF VALVE CONTRAPTION)
          (PART-OF MOUNT CONTRAPTION)
          (ASSEMBLE-ORDER DOODAD GIMCRACK BRACKET)
          (ASSEMBLE-ORDER KLUDGE THINGUMBOB HACK)
          (ASSEMBLE-ORDER KLUDGE THINGUMBOB HACK)
          (REMOVE-ORDER THINGUMBOB KLUDGE HACK)
          (ASSEMBLE-ORDER TUBE DOODAD PLUG)
          (ASSEMBLE-ORDER TUBE GIMCRACK PLUG)
          (REMOVE-ORDER DOODAD TUBE PLUG)
          (ASSEMBLE-ORDER DOODAD GIMCRACK PLUG)
          (REMOVE-ORDER GIMCRACK DOODAD PLUG)
          (ASSEMBLE-ORDER SPROCKET FROB CONNECTOR)
          (REMOVE-ORDER FROB SPROCKET CONNECTOR)
          (ASSEMBLE-ORDER FOOBAR SPROCKET CONNECTOR)
          (ASSEMBLE-ORDER TUBE DOODAD WHATSIS)
          (ASSEMBLE-ORDER TUBE GIMCRACK WHATSIS)
          (ASSEMBLE-ORDER DEVICE CONTRAPTION WHATSIS)
          (ASSEMBLE-ORDER VALVE WIDGET CONTRAPTION))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-15)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS DEVICE CONNECTOR WIDGET-2 FOOBAR FASTENER WHATSIS UNIT
             THINGUMBOB BRACKET SOCKET CONTRAPTION HOOZAWHATSIE PLUG KLUDGE
             WIDGET WIRE HACK GIMCRACK DOODAD COIL FROB TUBE SPROCKET VALVE
             MOUNT - ASSEMBLY
             HAMMOCK SCAFFOLD SCOPE - RESOURCE)
   (:INIT (AVAILABLE WIDGET-2)
          (AVAILABLE FASTENER)
          (AVAILABLE WHATSIS)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE BRACKET)
          (AVAILABLE SOCKET)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE PLUG)
          (AVAILABLE KLUDGE)
          (AVAILABLE WIDGET)
          (AVAILABLE WIRE)
          (AVAILABLE HACK)
          (AVAILABLE GIMCRACK)
          (AVAILABLE FROB)
          (AVAILABLE TUBE)
          (AVAILABLE VALVE)
          (AVAILABLE MOUNT)
          (REQUIRES CONNECTOR SCAFFOLD)
          (REQUIRES FOOBAR SCAFFOLD)
          (REQUIRES UNIT SCAFFOLD)
          (REQUIRES HOOZAWHATSIE SCAFFOLD)
          (REQUIRES DOODAD SCAFFOLD)
          (REQUIRES SPROCKET SCOPE)
          (PART-OF CONNECTOR DEVICE)
          (PART-OF UNIT DEVICE)
          (PART-OF HOOZAWHATSIE DEVICE)
          (PART-OF DOODAD DEVICE)
          (PART-OF WIDGET-2 CONNECTOR)
          (PART-OF FOOBAR CONNECTOR)
          (PART-OF FASTENER FOOBAR)
          (PART-OF WHATSIS FOOBAR)
          (PART-OF THINGUMBOB UNIT)
          (PART-OF BRACKET UNIT)
          (PART-OF SOCKET UNIT)
          (PART-OF CONTRAPTION UNIT)
          (PART-OF PLUG HOOZAWHATSIE)
          (PART-OF KLUDGE HOOZAWHATSIE)
          (PART-OF WIDGET HOOZAWHATSIE)
          (PART-OF WIRE HOOZAWHATSIE)
          (PART-OF HACK HOOZAWHATSIE)
          (PART-OF GIMCRACK HOOZAWHATSIE)
          (PART-OF COIL DOODAD)
          (PART-OF SPROCKET DOODAD)
          (PART-OF FROB COIL)
          (PART-OF TUBE COIL)
          (PART-OF VALVE SPROCKET)
          (PART-OF MOUNT SPROCKET)
          (ASSEMBLE-ORDER UNIT CONNECTOR DEVICE)
          (ASSEMBLE-ORDER DOODAD CONNECTOR DEVICE)
          (ASSEMBLE-ORDER WIRE PLUG HOOZAWHATSIE)
          (ASSEMBLE-ORDER SPROCKET COIL DOODAD)
          (ASSEMBLE-ORDER FROB TUBE COIL)
          (ASSEMBLE-ORDER VALVE MOUNT SPROCKET))
   (:GOAL (COMPLETE DEVICE)))

(DEFINE (PROBLEM ASSEM-16)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS BRACKET DOODAD WIDGET-1 WIRE-2 WIRE KLUDGE WHATSIS
             THINGUMBOB UNIT GIMCRACK SOCKET COIL SPROCKET FOOBAR MOUNT
             FASTENER DEVICE CONTRAPTION HOOZAWHATSIE VALVE FROB TUBE
             CONNECTOR PLUG HACK WIDGET - ASSEMBLY
             SCAFFOLD HAMMOCK - RESOURCE)
   (:INIT (AVAILABLE WIDGET-1)
          (AVAILABLE WIRE-2)
          (AVAILABLE WIRE)
          (AVAILABLE KLUDGE)
          (AVAILABLE WHATSIS)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE GIMCRACK)
          (AVAILABLE SOCKET)
          (AVAILABLE COIL)
          (AVAILABLE SPROCKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE MOUNT)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE FROB)
          (AVAILABLE TUBE)
          (AVAILABLE PLUG)
          (AVAILABLE HACK)
          (AVAILABLE WIDGET)
          (REQUIRES DOODAD SCAFFOLD)
          (REQUIRES UNIT HAMMOCK)
          (REQUIRES FASTENER HAMMOCK)
          (REQUIRES DEVICE HAMMOCK)
          (REQUIRES VALVE HAMMOCK)
          (REQUIRES CONNECTOR HAMMOCK)
          (PART-OF DOODAD BRACKET)
          (PART-OF UNIT BRACKET)
          (PART-OF FASTENER BRACKET)
          (PART-OF CONNECTOR BRACKET)
          (PART-OF WIDGET-1 DOODAD)
          (PART-OF WIRE-2 DOODAD)
          (PART-OF WIRE DOODAD)
          (PART-OF KLUDGE DOODAD)
          (PART-OF WHATSIS DOODAD)
          (PART-OF THINGUMBOB DOODAD)
          (PART-OF GIMCRACK UNIT)
          (PART-OF SOCKET UNIT)
          (PART-OF COIL UNIT)
          (PART-OF SPROCKET UNIT)
          (PART-OF FOOBAR UNIT)
          (PART-OF MOUNT UNIT)
          (PART-OF DEVICE FASTENER)
          (PART-OF VALVE FASTENER)
          (PART-OF CONTRAPTION DEVICE)
          (PART-OF HOOZAWHATSIE DEVICE)
          (PART-OF FROB VALVE)
          (PART-OF TUBE VALVE)
          (PART-OF PLUG CONNECTOR)
          (PART-OF HACK CONNECTOR)
          (PART-OF WIDGET CONNECTOR)
          (ASSEMBLE-ORDER UNIT CONNECTOR BRACKET)
          (ASSEMBLE-ORDER FASTENER DOODAD BRACKET)
          (ASSEMBLE-ORDER CONNECTOR DOODAD BRACKET)
          (ASSEMBLE-ORDER WIDGET-1 THINGUMBOB DOODAD)
          (ASSEMBLE-ORDER WIRE-2 WIRE DOODAD)
          (ASSEMBLE-ORDER WHATSIS WIRE DOODAD)
          (ASSEMBLE-ORDER DEVICE VALVE FASTENER)
          (ASSEMBLE-ORDER PLUG WIDGET CONNECTOR))
   (:GOAL (COMPLETE BRACKET)))

(DEFINE (PROBLEM ASSEM-17)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS HACK DOODAD-2 WHATSIS-4 SOCKET-1 SPROCKET THINGUMBOB
             WIRE PLUG COIL WIDGET TUBE GIMCRACK VALVE KLUDGE WHATSIS
             HOOZAWHATSIE BRACKET DOODAD UNIT FASTENER FOOBAR DEVICE - ASSEMBLY
             FILE TWEEZERS - RESOURCE)
   (:INIT (AVAILABLE WHATSIS-4)
          (AVAILABLE SOCKET-1)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE WIRE)
          (AVAILABLE COIL)
          (AVAILABLE WIDGET)
          (AVAILABLE TUBE)
          (AVAILABLE GIMCRACK)
          (AVAILABLE KLUDGE)
          (AVAILABLE WHATSIS)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE BRACKET)
          (AVAILABLE DOODAD)
          (AVAILABLE FOOBAR)
          (AVAILABLE DEVICE)
          (REQUIRES DOODAD-2 TWEEZERS)
          (REQUIRES SPROCKET TWEEZERS)
          (REQUIRES PLUG FILE)
          (REQUIRES VALVE TWEEZERS)
          (REQUIRES UNIT FILE)
          (REQUIRES FASTENER TWEEZERS)
          (PART-OF DOODAD-2 HACK)
          (PART-OF SPROCKET HACK)
          (PART-OF PLUG HACK)
          (PART-OF VALVE HACK)
          (PART-OF UNIT HACK)
          (PART-OF WHATSIS-4 DOODAD-2)
          (PART-OF SOCKET-1 DOODAD-2)
          (PART-OF GIMCRACK SPROCKET)
          (TRANSIENT-PART THINGUMBOB SPROCKET)
          (PART-OF WIRE SPROCKET)
          (PART-OF COIL PLUG)
          (PART-OF WIDGET PLUG)
          (PART-OF TUBE PLUG)
          (PART-OF THINGUMBOB PLUG)
          (TRANSIENT-PART GIMCRACK PLUG)
          (PART-OF KLUDGE VALVE)
          (PART-OF WHATSIS VALVE)
          (PART-OF HOOZAWHATSIE VALVE)
          (TRANSIENT-PART BRACKET VALVE)
          (PART-OF DOODAD VALVE)
          (PART-OF BRACKET UNIT)
          (PART-OF FASTENER UNIT)
          (PART-OF FOOBAR FASTENER)
          (PART-OF DEVICE FASTENER)
          (ASSEMBLE-ORDER DOODAD-2 SPROCKET HACK)
          (ASSEMBLE-ORDER DOODAD-2 VALVE HACK)
          (ASSEMBLE-ORDER PLUG UNIT HACK)
          (ASSEMBLE-ORDER WHATSIS-4 SOCKET-1 DOODAD-2)
          (ASSEMBLE-ORDER GIMCRACK COIL SPROCKET)
          (ASSEMBLE-ORDER THINGUMBOB WIRE SPROCKET)
          (REMOVE-ORDER WIRE THINGUMBOB SPROCKET)
          (ASSEMBLE-ORDER THINGUMBOB WIRE PLUG)
          (ASSEMBLE-ORDER GIMCRACK COIL PLUG)
          (REMOVE-ORDER COIL GIMCRACK PLUG)
          (ASSEMBLE-ORDER HOOZAWHATSIE DOODAD VALVE)
          (ASSEMBLE-ORDER HOOZAWHATSIE WHATSIS VALVE)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE VALVE)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE VALVE)
          (REMOVE-ORDER HOOZAWHATSIE BRACKET VALVE)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE UNIT)
          (ASSEMBLE-ORDER BRACKET HOOZAWHATSIE UNIT)
          (ASSEMBLE-ORDER FOOBAR DEVICE FASTENER))
   (:GOAL (COMPLETE HACK)))

(DEFINE (PROBLEM ASSEM-18)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS SOCKET DEVICE DOODAD-3 KLUDGE-4 HACK-1 GIMCRACK-2 FROB
             VALVE TUBE PLUG DOODAD KLUDGE SPROCKET WIRE HACK BRACKET
             WIDGET UNIT CONNECTOR HOOZAWHATSIE THINGUMBOB FASTENER
             GIMCRACK CONTRAPTION FOOBAR WHATSIS COIL MOUNT - ASSEMBLY
             HAMMOCK CLAMP - RESOURCE)
   (:INIT (AVAILABLE DOODAD-3)
          (AVAILABLE KLUDGE-4)
          (AVAILABLE HACK-1)
          (AVAILABLE GIMCRACK-2)
          (AVAILABLE VALVE)
          (AVAILABLE TUBE)
          (AVAILABLE DOODAD)
          (AVAILABLE KLUDGE)
          (AVAILABLE WIRE)
          (AVAILABLE HACK)
          (AVAILABLE BRACKET)
          (AVAILABLE UNIT)
          (AVAILABLE CONNECTOR)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE GIMCRACK)
          (AVAILABLE CONTRAPTION)
          (AVAILABLE FOOBAR)
          (AVAILABLE WHATSIS)
          (AVAILABLE COIL)
          (AVAILABLE MOUNT)
          (REQUIRES DEVICE CLAMP)
          (REQUIRES FROB HAMMOCK)
          (REQUIRES PLUG CLAMP)
          (REQUIRES SPROCKET CLAMP)
          (REQUIRES WIDGET CLAMP)
          (REQUIRES FASTENER CLAMP)
          (PART-OF DEVICE SOCKET)
          (PART-OF FROB SOCKET)
          (PART-OF PLUG SOCKET)
          (PART-OF WIDGET SOCKET)
          (PART-OF FASTENER SOCKET)
          (PART-OF DOODAD-3 DEVICE)
          (PART-OF KLUDGE-4 DEVICE)
          (PART-OF HACK-1 DEVICE)
          (PART-OF GIMCRACK-2 DEVICE)
          (PART-OF VALVE FROB)
          (PART-OF TUBE FROB)
          (PART-OF DOODAD PLUG)
          (PART-OF KLUDGE PLUG)
          (PART-OF SPROCKET PLUG)
          (PART-OF WIRE SPROCKET)
          (PART-OF HACK SPROCKET)
          (PART-OF BRACKET SPROCKET)
          (PART-OF UNIT WIDGET)
          (PART-OF CONNECTOR WIDGET)
          (PART-OF HOOZAWHATSIE WIDGET)
          (PART-OF THINGUMBOB WIDGET)
          (PART-OF GIMCRACK FASTENER)
          (PART-OF CONTRAPTION FASTENER)
          (PART-OF FOOBAR FASTENER)
          (PART-OF WHATSIS FASTENER)
          (PART-OF COIL FASTENER)
          (PART-OF MOUNT FASTENER)
          (ASSEMBLE-ORDER PLUG DEVICE SOCKET)
          (ASSEMBLE-ORDER WIDGET PLUG SOCKET)
          (ASSEMBLE-ORDER DOODAD-3 KLUDGE-4 DEVICE)
          (ASSEMBLE-ORDER HACK-1 DOODAD-3 DEVICE)
          (ASSEMBLE-ORDER GIMCRACK-2 DOODAD-3 DEVICE)
          (ASSEMBLE-ORDER VALVE TUBE FROB)
          (ASSEMBLE-ORDER DOODAD SPROCKET PLUG)
          (ASSEMBLE-ORDER HOOZAWHATSIE UNIT WIDGET)
          (ASSEMBLE-ORDER THINGUMBOB HOOZAWHATSIE WIDGET))
   (:GOAL (COMPLETE SOCKET)))

(DEFINE (PROBLEM ASSEM-19)
   (:DOMAIN ASSEMBLY)
   (:OBJECTS VALVE DEVICE BRACKET-8 COIL-3 WIRE-4 FOOBAR-1
             HOOZAWHATSIE-2 MOUNT GIMCRACK PLUG SPROCKET DOODAD COIL WIDGET
             CONTRAPTION HACK THINGUMBOB CONNECTOR UNIT KLUDGE FROB FASTENER
             SOCKET WIRE HOOZAWHATSIE BRACKET FOOBAR WHATSIS - ASSEMBLY
             PLIERS VOLTMETER - RESOURCE)
   (:INIT (AVAILABLE BRACKET-8)
          (AVAILABLE COIL-3)
          (AVAILABLE WIRE-4)
          (AVAILABLE FOOBAR-1)
          (AVAILABLE HOOZAWHATSIE-2)
          (AVAILABLE MOUNT)
          (AVAILABLE GIMCRACK)
          (AVAILABLE PLUG)
          (AVAILABLE DOODAD)
          (AVAILABLE COIL)
          (AVAILABLE WIDGET)
          (AVAILABLE HACK)
          (AVAILABLE THINGUMBOB)
          (AVAILABLE CONNECTOR)
          (AVAILABLE KLUDGE)
          (AVAILABLE FROB)
          (AVAILABLE SOCKET)
          (AVAILABLE WIRE)
          (AVAILABLE HOOZAWHATSIE)
          (AVAILABLE BRACKET)
          (AVAILABLE FOOBAR)
          (AVAILABLE WHATSIS)
          (REQUIRES DEVICE VOLTMETER)
          (REQUIRES SPROCKET VOLTMETER)
          (REQUIRES CONTRAPTION PLIERS)
          (REQUIRES UNIT VOLTMETER)
          (REQUIRES FASTENER PLIERS)
          (PART-OF DEVICE VALVE)
          (PART-OF SPROCKET VALVE)
          (PART-OF CONTRAPTION VALVE)
          (PART-OF UNIT VALVE)
          (PART-OF FASTENER VALVE)
          (PART-OF BRACKET-8 DEVICE)
          (PART-OF COIL-3 DEVICE)
          (PART-OF WIRE-4 DEVICE)
          (PART-OF FOOBAR-1 DEVICE)
          (PART-OF HOOZAWHATSIE-2 DEVICE)
          (PART-OF MOUNT DEVICE)
          (PART-OF GIMCRACK DEVICE)
          (PART-OF PLUG DEVICE)
          (PART-OF DOODAD SPROCKET)
          (PART-OF COIL SPROCKET)
          (PART-OF WIDGET SPROCKET)
          (TRANSIENT-PART HACK CONTRAPTION)
          (PART-OF THINGUMBOB CONTRAPTION)
          (PART-OF CONNECTOR CONTRAPTION)
          (PART-OF KLUDGE UNIT)
          (PART-OF FROB UNIT)
          (PART-OF HACK UNIT)
          (PART-OF SOCKET FASTENER)
          (PART-OF WIRE FASTENER)
          (PART-OF HOOZAWHATSIE FASTENER)
          (PART-OF BRACKET FASTENER)
          (PART-OF FOOBAR FASTENER)
          (PART-OF WHATSIS FASTENER)
          (ASSEMBLE-ORDER DEVICE CONTRAPTION VALVE)
          (ASSEMBLE-ORDER DEVICE UNIT VALVE)
          (ASSEMBLE-ORDER UNIT SPROCKET VALVE)
          (ASSEMBLE-ORDER FASTENER CONTRAPTION VALVE)
          (ASSEMBLE-ORDER BRACKET-8 MOUNT DEVICE)
          (ASSEMBLE-ORDER COIL-3 GIMCRACK DEVICE)
          (ASSEMBLE-ORDER WIRE-4 PLUG DEVICE)
          (ASSEMBLE-ORDER MOUNT GIMCRACK DEVICE)
          (ASSEMBLE-ORDER PLUG BRACKET-8 DEVICE)
          (ASSEMBLE-ORDER PLUG HOOZAWHATSIE-2 DEVICE)
          (ASSEMBLE-ORDER COIL DOODAD SPROCKET)
          (ASSEMBLE-ORDER WIDGET DOODAD SPROCKET)
          (ASSEMBLE-ORDER HACK CONNECTOR CONTRAPTION)
          (REMOVE-ORDER CONNECTOR HACK CONTRAPTION)
          (ASSEMBLE-ORDER FROB KLUDGE UNIT)
          (ASSEMBLE-ORDER HACK CONNECTOR UNIT)
          (ASSEMBLE-ORDER WIRE SOCKET FASTENER)
          (ASSEMBLE-ORDER HOOZAWHATSIE BRACKET FASTENER)
          (ASSEMBLE-ORDER BRACKET WIRE FASTENER)
          (ASSEMBLE-ORDER BRACKET FOOBAR FASTENER))
   (:GOAL (COMPLETE VALVE)))

